require_relative 'help'

###################################
# An interface to Loriot Service from Ruby
###################################
class LoriotClient
  include LoriotRb::Base

  # Establish a secure connection to your account on the cloud
  def initialize(options = {})
    options = { debug: false,
                token: LoriotRb::Settings.token,
                appid: LoriotRb::Settings.appid,
                host: LoriotRb.configuration.host,
                port: LoriotRb.configuration.port }.merge(options)
    @debug = options[:debug]
    @token = options[:token]
    @appid = options[:appid]
    options

    welcome_response = sub_initialize(options)

    raise("Loriot-rb: Cannot connect to host #{options[:host]}:#{options[:port]}") unless welcome_response.index('hello')

  end

  # Send the request to device
  def send_cmd(options = {})
    options = { debug: @debug,
                token: @token,
                appid: @appid,
                cmd: "tx",
                eui: nil,
                port: 40,
                confirmed: false,
                data: "0301"}.merge(options)

    raise("Eui is blank! Should i guess your device?") unless options[:eui]
    response = sub_send_cmd(options)
    puts "#{Time.now} Cmd response: #{response}" if options[:debug]
    response
  end

  # Receive all data devices from the cloud
  # Each device sends its data to the cloud
  def read_data(options = {})
    options = { debug: @debug }.merge(options)
    puts "#{Time.now} Waiting for #{@appid} incoming data..." if options[:debug]
    response = sub_read_data(options)
    puts "#{Time.now} Received: #{response}" if options[:debug]
    response
  end

  # Stay awaiting data from the cloud
  def listen(options = {}, &block)
    options = { debug: @debug }.merge(options)

    puts "#{Time.now} Starting Listen #{@appid}" if options[:debug]
    response = nil
    begin
      response = read_data(options)
      block.call(response) if block
    end while response && !options[:test]
    # Return last response
    response
  end

  # Close the secure connection with the cloud
  def quit
    sub_quit
  end
end
